"use strict";
/*!
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const AgentConfig_1 = tslib_1.__importDefault(require("../../../../config/AgentConfig"));
const grpc = tslib_1.__importStar(require("@grpc/grpc-js"));
const grpc_js_1 = require("@grpc/grpc-js");
const logging_1 = require("../../../../logging");
const Tracing_grpc_pb_1 = require("../../../../proto/language-agent/Tracing_grpc_pb");
const AuthInterceptor_1 = tslib_1.__importDefault(require("../AuthInterceptor"));
const SegmentObjectAdapter_1 = tslib_1.__importDefault(require("../SegmentObjectAdapter"));
const EventEmitter_1 = require("../../../../lib/EventEmitter");
const logger = logging_1.createLogger(__filename);
class TraceReportClient {
    constructor() {
        this.buffer = [];
        this.reporterClient = new Tracing_grpc_pb_1.TraceSegmentReportServiceClient(AgentConfig_1.default.collectorAddress, AgentConfig_1.default.secure ? grpc.credentials.createSsl() : grpc.credentials.createInsecure(), { interceptors: [AuthInterceptor_1.default] });
        EventEmitter_1.emitter.on('segment-finished', (segment) => {
            var _a;
            this.buffer.push(segment);
            (_a = this.timeout) === null || _a === void 0 ? void 0 : _a.ref();
        });
    }
    get isConnected() {
        var _a;
        return ((_a = this.reporterClient) === null || _a === void 0 ? void 0 : _a.getChannel().getConnectivityState(true)) === grpc_js_1.connectivityState.READY;
    }
    start() {
        const reportFunction = () => {
            EventEmitter_1.emitter.emit('segments-sent'); // reset limiter in SpanContext
            try {
                if (this.buffer.length === 0) {
                    return;
                }
                const stream = this.reporterClient.collect((error, _) => {
                    if (error) {
                        logger.error('Failed to report trace data', error);
                    }
                });
                try {
                    for (const segment of this.buffer) {
                        if (segment) {
                            if (logger._isDebugEnabled) {
                                logger.debug('Sending segment ', { segment });
                            }
                            stream.write(new SegmentObjectAdapter_1.default(segment));
                        }
                    }
                }
                finally {
                    this.buffer.length = 0;
                }
                stream.end();
            }
            finally {
                this.timeout = setTimeout(reportFunction, 1000).unref();
            }
        };
        this.timeout = setTimeout(reportFunction, 1000).unref();
    }
}
exports.default = TraceReportClient;
//# sourceMappingURL=TraceReportClient.js.map